# -*- coding: utf-8 -*-

import numpy as np
from skimage import measure

__all__ = ['detect_edges',
           ]


def detect_edges(image, **kwargs):
    """
    Detect the edge of the drop on the image.

    Parameters
    ----------
    image : ndarray
        Grayscale image.
    kwargs : dict, optional
        Optional arguments passed to `find_contours`.

    Returns
    -------
    results : tuple
        (edges, R_edges, Z_edges)

    Notes
    -----
    `contour` method calls `skimage.measure.find_countours`.
    The default level is the average of the max and min intensity
    values.
    """
    # By default:
    # Use the mean grayscale value of the image to get the contour.
    contour_kwargs = {'level': 0.5 * (image.max() + image.min())}
    contour_kwargs.update(**kwargs)

    contours = measure.find_contours(image, **contour_kwargs)
    Z_edges, R_edges = np.column_stack(contours[0])

    # Make a binary image
    edges = np.full(image.shape, False, dtype=bool)
    edges[Z_edges.astype(int), R_edges.astype(int)] = True

    return edges, (R_edges, Z_edges)
